<?php
/**
 * @file
 * Hooks provided by the Pirobox module.
 */

/**
 * Returns formatter settings form elements.
 *
 * @param $element
 *   The associative array contains the settings form elements to alter.
 * @param $vars
 *   The associative array contains various parameters to help to alter.
 *
 * @ingroup hooks
 */
function hook_pirobox_field_formatter_settings_form_get_element_alter(&$element, $vars) {
  $settings = $vars['display']['settings'];

  $description = t('Limiting the number of images that are displayed. If used, only users with the permission <em>View Pirobox limited galleries</em> can see full galleries.');
  $description .= '<br />' . t('Please choose the number of displayed images.');
  $element['pirobox_gallery_limit'] = array(
    '#type' => 'select',
    '#title' => t('Gallery limitation'),
    '#description' => $description,
    '#default_value' => $settings['pirobox_gallery_limit'],
    '#options' => _pirobox_limit_gallery_limit_options(),
    '#weight' => -1
  );
}

/**
 * Returns formatter settings HTML.
 *
 * @param $summary
 *   The associative array contains the settings HTML content to alter.
 * @param $vars
 *   The associative array contains various parameters to help to alter.
 *
 * @ingroup hooks
 */
function hook_pirobox_field_formatter_settings_summary_get_summary_alter(&$summary, $vars) {
  $settings = $vars['settings'];

  if (isset($settings['pirobox_gallery_limit'])) {
    $gallery_limit_options = _pirobox_limit_gallery_limit_options();

    $summary[] = t('Pirobox gallery limitation: @type', array('@type' => $gallery_limit_options[$settings['pirobox_gallery_limit']]));
  }
  if (isset($settings['pirobox_gallery_limit_bypass'])) {
    $gallery_limit_bypass_options = _pirobox_limit_gallery_limit_bypass_options();

    $summary[] = t('Pirobox gallery limitation bypass: @type', array('@type' => $gallery_limit_bypass_options[$settings['pirobox_gallery_limit_bypass']]));
  }
}

/**
 * Returns a renderable array for a field value.
 *
 * @param $items
 *   The associative array contains the items to alter.
 * @param $vars
 *   The associative array contains various parameters to help to alter.
 *
 * @ingroup hooks
 */
function hook_pirobox_field_formatter_view_alter(&$items, $vars) {
  global $user;

  $settings = $vars['display']['settings'];
  $entity = $vars['entity'];
  $owner_access = FALSE;

  if ($user->uid == $entity->uid && (bool) $settings['pirobox_gallery_limit_bypass']) {
    $owner_access = TRUE;
  }

  if ($settings['pirobox_gallery_limit'] == 0 || $owner_access) {
    return;
  }
  if (user_access('view pirobox limited galleries', $user)) {
    return;
  }

  switch(variable_get('pirobox_limit_extra_style', FALSE)) {
    case 0:
      if (count($items)) {
        array_splice($items, $settings['pirobox_gallery_limit']);
      }
      break;

    case 1:
      if (count($items)) {
        array_splice($items, $settings['pirobox_gallery_limit'] + variable_get('pirobox_limit_limited_images', 1));
      }
      break;
  }
}

/**
 * Returns settings that are used by field formatter info.
 *
 * @param $settings
 *   The associative array contains the formatter settings to alter.
 *
 * @return
 *   An associative array contains field formatter settings.
 *
 * @ingroup hooks
 */
function hook_pirobox_field_formatter_get_settings_alter(&$settings) {
  $settings['pirobox_gallery_limit'] = FALSE;
  // Allow full gallery view access for the content owner.
  $settings['pirobox_gallery_limit_bypass'] = FALSE;
}

/**
 * Returns a string for the Pirobox caption.
 *
 * @param $caption
 *   HTML caption text to alter.
 * @param $variables
 *   The associative array contains the formatter settings to alter.
 *
 * @return
 *   A string can contain HTML code. The string are not sanitized.
 *
 * @ingroup hooks
 */
function hook_pirobox_formatter_caption_alter(&$caption, $variables) {
  global $user;

  $pirobox_limit_extra_caption = variable_get('pirobox_limit_extra_caption', array('value' => '', 'format' => NULL));

  if (empty($pirobox_limit_extra_caption['value'])) {
    return;
  }

  // Only a limited gallery image uses the extra caption text.
  // The Pirobox jQuery plugin JS needs the caption text
  // without p tag on begin and end.
  if ($variables['image_style_extra'] == TRUE) {
    $caption = preg_replace("/^<p>|<\/p>$/", '', $pirobox_limit_extra_caption['value']);
  }
}

/**
 * Allows to alter form elements on Pirobox image fields on content edit forms.
 *
 * @param $element
 *   The associative array contains elements to alter.
 * @param $vars
 *   The associative array contains the form elements to alter.
 *
 * @ingroup hooks
 */
function hook_pirobox_imagefield_widget_process_alter(&$element, $vars) {
  $instance = $vars['instance'];
  $displays = array();

  $gallery_limit = FALSE;
  foreach (element_children($instance['display']) as $display) {
    if (isset($instance['display'][$display]['settings']['pirobox_gallery_limit'])) {
      $gallery_limit = TRUE;
      $displays[$display] = $instance['display'][$display]['settings']['pirobox_gallery_limit'];
    }
  }

  if ($gallery_limit == TRUE && isset($element['filename'])) {
    $filename = $element['filename']['#markup'];

    $message = t('Pirobox <em>image limitation</em> is active. Not all images displayed for all visitors.');
    $message .= _pirobox_limit_get_limit_info($displays);
    $message .= t('The number of used images is counted from the first image in this list.');

    $element['filename']['#markup'] = '<div class="description pirobox-limit-description">' . $message . '</div>' . $filename;
  }
}

/**
 * Returns an URL.
 *
 * @param $uri
 *   An string containing the URI for which we need an URL.
 *
 * @return
 *   An string containing an URL.
 *
 * @see pirobox.theme.inc|theme_pirobox_formatter()
 *
 * @ingroup hooks
 */
function hook_pirobox_image_path_alter($uri) {
  global $base_url;

  // @see http://drupal.org/node/1149910

  $scheme = file_uri_scheme($uri);

  if (variable_get('pirobox_relative_paths', FALSE) == TRUE && ($scheme == 'public' || $scheme == 'private')) {
    $base = $base_url . '/';
    $matches = array();

    if (preg_match('/^[\w\d]+:\/\/.*?\//', $base, $matches)) {
      $base = drupal_substr($matches[0], 0, -1);
      $uri = str_replace($base, '', file_create_url($uri));
    }
  }
}
